@@ -178,7 +178,7 @@ type InboxSource interface {
 	Search(ctx context.Context, uid gregor1.UID, query string, limit int,
 		emptyMode InboxSourceSearchEmptyMode) ([]RemoteConversation, error)
 	MarkAsRead(ctx context.Context, convID chat1.ConversationID, uid gregor1.UID,
-		msgID *chat1.MessageID) error
+		msgID *chat1.MessageID, forceUnread bool) error
 	Draft(ctx context.Context, uid gregor1.UID, convID chat1.ConversationID, text *string) error
 	NotifyUpdate(ctx context.Context, uid gregor1.UID, convID chat1.ConversationID)
 	IncrementLocalConvVersion(ctx context.Context, uid gregor1.UID, convID chat1.ConversationID) (*chat1.ConversationLocal, error)
