@@ -7,7 +7,6 @@
 package install
 
 import (
-	"io/ioutil"
 	"testing"
 
 	"os"
@@ -25,7 +24,7 @@ func TestIsInUse(t *testing.T) {
 	// Should be false if no special file is present
 	require.False(t, IsInUse("", tc.G.Log))
 
-	tmpdir, err := ioutil.TempDir("", "TestIsInUse")
+	tmpdir, err := os.MkdirTemp("", "TestIsInUse")
 	assert.Nil(t, err, "can't create temp tmpdir")
 
 	signalFileName := filepath.Join(tmpdir, ".kbfs_number_of_handles")
@@ -34,14 +33,14 @@ func TestIsInUse(t *testing.T) {
 	require.False(t, IsInUse(tmpdir, tc.G.Log))
 
 	d := []byte("5")
-	assert.Nil(t, ioutil.WriteFile(signalFileName, d, 0644))
+	assert.Nil(t, os.WriteFile(signalFileName, d, 0644))
 	defer os.Remove(signalFileName)
 
 	// Should be true if special file has a number
 	require.True(t, IsInUse(tmpdir, tc.G.Log))
 
 	d = []byte("0")
-	assert.Nil(t, ioutil.WriteFile(signalFileName, d, 0644))
+	assert.Nil(t, os.WriteFile(signalFileName, d, 0644))
 
 	// Should be false if special file has a zero
 	require.False(t, IsInUse(tmpdir, tc.G.Log))
