@@ -17,6 +17,8 @@ import (
 	"github.com/keybase/go-framed-msgpack-rpc/rpc"
 	"golang.org/x/net/context"
 
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
 	"golang.org/x/text/unicode/norm"
 )
 
@@ -625,7 +627,8 @@ func (h *UserSearchHandler) GetNonUserDetails(ctx context.Context, arg keybase1.
 	assertion := url.String()
 
 	if url.IsSocial() {
-		res.Description = fmt.Sprintf("%s user", strings.Title(service))
+		caser := cases.Title(language.AmericanEnglish)
+		res.Description = fmt.Sprintf("%s user", caser.String(service))
 		apiRes, err := h.makeSearchRequest(mctx, keybase1.UserSearchArg{
 			Query:                  username,
 			Service:                service,
