@@ -17,7 +17,7 @@ build=""
 if [ ! "$mode" = "production" ] ; then
   current_date="$(date -u +%Y%m%d%H%M%S)" # UTC
   commit_short="$(git -C "$here" log -1 --pretty=format:%h || \
-    echo -n ${SOURCE_COMMIT:0:10})"
+    echo -n "${SOURCE_COMMIT:0:10}")"
   build="-$current_date+$commit_short"
 fi
 
