@@ -1,46 +1,39 @@
 import * as React from 'react'
 import * as Kb from '../../../../../common-adapters/mobile.native'
 import * as Styles from '../../../../../styles'
+import * as Container from '../../../../../util/container'
 import type {Props} from '.'
 
 const lightPatternImage = require('../../../../../images/payment-pattern-80.png')
 const darkPatternImage = require('../../../../../images/dark-payment-pattern-80.png')
 
-type State = {
-  yOffset: Kb.NativeAnimated.Value
-}
+const PendingBackground = (p: Props) => {
+  const {children, style} = p
+  const offset = React.useRef(new Kb.NativeAnimated.Value(0)).current
 
-class PendingBackground extends React.Component<Props, State> {
-  state = {yOffset: new Kb.NativeAnimated.Value(0)}
-
-  componentDidMount() {
+  Container.useOnMountOnce(() => {
     Kb.NativeAnimated.loop(
-      Kb.NativeAnimated.timing(this.state.yOffset, {
+      Kb.NativeAnimated.timing(offset, {
         duration: 2000,
         easing: Kb.NativeEasing.linear,
         toValue: -80,
         useNativeDriver: true,
       })
     ).start()
-  }
+  })
 
-  render() {
-    return (
-      <>
-        <Kb.NativeAnimated.Image
-          resizeMode="repeat"
-          source={Styles.isDarkMode() ? darkPatternImage : lightPatternImage}
-          style={Styles.collapseStyles([
-            styles.image,
-            {
-              transform: [{translateY: this.state.yOffset}] as any,
-            },
-          ])}
-        />
-        {this.props.children}
-      </>
-    )
-  }
+  const source = Styles.isDarkMode() ? darkPatternImage : lightPatternImage
+
+  return (
+    <Kb.Box2 direction="vertical" style={style}>
+      <Kb.NativeAnimated.Image
+        resizeMode="repeat"
+        source={source}
+        style={[styles.image, {transform: [{translateY: offset}] as any}]}
+      />
+      {children}
+    </Kb.Box2>
+  )
 }
 
 const styles = Styles.styleSheetCreate(
