@@ -18,6 +18,7 @@ import type {TypedState} from '../reducer'
 import {assertNever} from '../../util/container'
 import {isMobile} from '../platform'
 import {noConversationIDKey} from '../types/chat2/common'
+import isEqual from 'lodash/isEqual'
 
 export const getMessageStateExtras = (state: TypedState, conversationIDKey: Types.ConversationIDKey) => {
   const getLastOrdinal = () =>
@@ -71,8 +72,8 @@ export const getPaymentMessageInfo = (
   )
 }
 
-export const isPendingPaymentMessage = (state: TypedState, message: Types.Message) => {
-  if (message.type !== 'sendPayment') {
+export const isPendingPaymentMessage = (state: TypedState, message?: Types.Message) => {
+  if (message?.type !== 'sendPayment') {
     return false
   }
   const paymentInfo = getPaymentMessageInfo(state, message)
@@ -196,8 +197,6 @@ const makeMessageExplodable = {
   explodingUnreadable: false,
 }
 
-export const howLongBetweenTimestampsMs: number = 1000 * 60 * 15
-
 export const makeMessagePlaceholder = (
   m?: Partial<MessageTypes.MessagePlaceholder>
 ): MessageTypes.MessagePlaceholder => ({
@@ -366,7 +365,7 @@ const makeMessageSystemAddedToTeam = (
   ...makeMessageCommonNoDeleteNoEdit,
   addee: '',
   adder: '',
-  bulkAdds: Array(),
+  bulkAdds: [],
   reactions: new Map(),
   role: 'none',
   team: '',
@@ -810,6 +809,7 @@ const uiMessageToSystemMessage = (
 
 export const isVideoAttachment = (message: Types.MessageAttachment) => message.fileType.startsWith('video')
 
+export const maxAmpsLength = 60
 export const previewSpecs = (
   preview: RPCChatTypes.AssetMetadata | null,
   full: RPCChatTypes.AssetMetadata | null
@@ -839,6 +839,7 @@ export const previewSpecs = (
       }
     }
     res.audioAmps = preview.image.audioAmps || []
+    res.audioAmps.length = Math.min(res.audioAmps.length, maxAmpsLength)
   } else if (preview.assetType === RPCChatTypes.AssetMetadataType.video && preview.video) {
     res.height = preview.video.height
     res.width = preview.video.width
@@ -1140,7 +1141,7 @@ const outboxUIMessagetoMessage = (
       const title = o.title
       const fileName = o.filename
       let previewURL = ''
-      let pre = previewSpecs(null, null)
+      let pre
       if (o.preview) {
         previewURL =
           o.preview.location && o.preview.location.ltyp === RPCChatTypes.PreviewLocationTyp.url
@@ -1149,6 +1150,8 @@ const outboxUIMessagetoMessage = (
         const md = (o.preview && o.preview.metadata) || null
         const baseMd = (o.preview && o.preview.baseMetadata) || null
         pre = previewSpecs(md, baseMd)
+      } else {
+        pre = previewSpecs(null, null)
       }
       return makePendingAttachmentMessage(
         conversationIDKey,
@@ -1233,13 +1236,21 @@ const journeycardUIMessageToMessage = (
   conversationIDKey: Types.ConversationIDKey,
   m: RPCChatTypes.UIMessageJourneycard
 ) => {
-  return makeMessageJourneycard({
-    cardType: m.cardType,
-    conversationIDKey,
-    highlightMsgID: m.highlightMsgID,
-    openTeam: m.openTeam,
-    ordinal: Types.numberToOrdinal(m.ordinal),
-  })
+  // only support these now
+  if (
+    m.cardType === RPCChatTypes.JourneycardType.welcome ||
+    m.cardType === RPCChatTypes.JourneycardType.popularChannels
+  ) {
+    return makeMessageJourneycard({
+      cardType: m.cardType,
+      conversationIDKey,
+      highlightMsgID: m.highlightMsgID,
+      openTeam: m.openTeam,
+      ordinal: Types.numberToOrdinal(m.ordinal),
+    })
+  }
+
+  return null
 }
 
 export const uiMessageToMessage = (
@@ -1272,8 +1283,8 @@ export const uiMessageToMessage = (
       return placeholderUIMessageToMessage(conversationIDKey, uiMessage.placeholder)
     case RPCChatTypes.MessageUnboxedState.journeycard:
       return journeycardUIMessageToMessage(conversationIDKey, uiMessage.journeycard)
-    default:
-      assertNever(uiMessage) // A type error here means there is an unhandled message state
+    default: // A type error here means there is an unhandled message state
+      assertNever(uiMessage)
       return null
   }
 }
@@ -1342,6 +1353,7 @@ export const makePendingAttachmentMessage = (
     exploding,
     fileName: fileName,
     id: Types.numberToMessageID(0),
+    inlineVideoPlayable: previewSpec.showPlayButton,
     isCollapsed: false,
     ordinal: ordinal,
     outboxID: outboxID,
@@ -1379,11 +1391,22 @@ export const getClientPrev = (
 }
 
 const imageFileNameRegex = /[^/]+\.(jpg|png|gif|jpeg|bmp)$/i
-export const pathToAttachmentType = (path: string) => (imageFileNameRegex.test(path) ? 'image' : 'file')
+const videoFileNameRegex = /[^/]+\.(mp4|mov|avi|mkv)$/i
+export const pathToAttachmentType = (path: string) => {
+  if (imageFileNameRegex.test(path)) {
+    return 'image'
+  }
+  if (videoFileNameRegex.test(path)) {
+    return 'video'
+  }
+  return 'file'
+}
 export const isSpecialMention = (s: string) => ['here', 'channel', 'everyone'].includes(s)
 
 export const specialMentions = ['here', 'channel', 'everyone']
 
+// TODO maybe its better to avoid merging at all and just deal with it at the component level. we pay for merging
+// on non visible items so the cost might be higher
 export const mergeMessage = (old: Types.Message | null, m: Types.Message): Types.Message => {
   if (!old) {
     return m
@@ -1394,31 +1417,36 @@ export const mergeMessage = (old: Types.Message | null, m: Types.Message): Types
     return m
   }
 
-  const toRet: any = {...m}
+  let toRet: any = {...m}
 
+  // if all props are the same then just use old
+  let allSame = true
   Object.keys(old).forEach(key => {
     switch (key) {
-      case 'mentionsAt':
-        if (
-          m.type === 'text' &&
-          old.type === 'text' &&
-          shallowEqual([...old.mentionsAt], [...m.mentionsAt])
-        ) {
-          toRet.mentionsAt = old.mentionsAt
-        }
-        break
       case 'mentionsChannelName':
-        if (
-          m.type === 'text' &&
-          old.type === 'text' &&
-          shallowEqual([...old.mentionsChannelName.entries()], [...m.mentionsChannelName].entries())
-        ) {
-          toRet.mentionsChannelName = old.mentionsChannelName
+      case 'reactions':
+      case 'mentionsAt':
+      case 'audioAmps':
+        if (shallowEqual([...old[key]], [...m[key]])) {
+          toRet[key] = old[key]
+        } else {
+          allSame = false
         }
         break
+      case 'bodySummary':
+      case 'decoratedText':
       case 'text':
-        if (m.type === 'text' && old.type === 'text' && old.text.stringValue() === m.text.stringValue()) {
-          toRet.text = old.text
+        if (old[key]?.stringValue?.() === m[key]?.stringValue?.()) {
+          toRet[key] = old[key]
+        } else {
+          allSame = false
+        }
+        break
+      case 'unfurls':
+        if (isEqual(m[key], old[key])) {
+          toRet[key] = old[key]
+        } else {
+          allSame = false
         }
         break
       default:
@@ -1426,10 +1454,14 @@ export const mergeMessage = (old: Types.Message | null, m: Types.Message): Types
         if (old[key] === m[key]) {
           // @ts-ignore strict
           toRet[key] = old[key]
+        } else {
+          allSame = false
         }
     }
   })
-
+  if (allSame) {
+    toRet = old
+  }
   return toRet
 }
 
@@ -1482,22 +1514,16 @@ export const upgradeMessage = (old: Types.Message, m: Types.Message): Types.Mess
     }
   }
 
+  // we never want to convert a non placeholder into a placeholder
+  if (m.type === 'placeholder' && old.type !== 'placeholder') {
+    return old
+  }
+
   return m
 }
 
-export const enoughTimeBetweenMessages = (
-  message: MessageTypes.Message,
-  previous?: MessageTypes.Message
-): boolean =>
-  Boolean(
-    previous &&
-      previous.timestamp &&
-      message.timestamp &&
-      message.timestamp - previous.timestamp > howLongBetweenTimestampsMs
-  )
-
-export const shouldShowPopup = (state: TypedState, message: Types.Message) => {
-  switch (message.type) {
+export const shouldShowPopup = (state: TypedState, message?: Types.Message) => {
+  switch (message?.type) {
     case 'text':
     case 'attachment':
     case 'requestPayment':
