@@ -17,11 +17,11 @@ export const SignInput = () => {
     }
   }, [dispatch])
   return (
-    <>
+    <Kb.KeyboardAvoidingView2>
       <OperationBanner operation={operation} />
       <Input operation={operation} />
       <InputActionsBar operation={operation} />
-    </>
+    </Kb.KeyboardAvoidingView2>
   )
 }
 export const SignOutput = () => (
@@ -34,14 +34,4 @@ export const SignOutput = () => (
   </>
 )
 
-SignInput.navigationOptions = {
-  headerShown: true,
-  title: 'Sign',
-}
-SignOutput.navigationOptions = {
-  headerLeft: p => <Kb.HeaderLeftCancel {...p} />,
-  headerShown: true,
-  title: 'Sign',
-}
-
 export default SignInput
