@@ -2,23 +2,24 @@ import * as React from 'react'
 import {Provider} from 'react-redux'
 import {GlobalKeyEventHandler} from '../../util/key-event-handler.desktop'
 import {GatewayProvider} from '@chardskarth/react-gateway'
-import {StyleContext} from '../../styles'
+import {CanFixOverdrawContext} from '../../styles'
 import './style.css'
 
 // if we want to load the read profiler before the app is loaded
 const deferLoadingApp = __DEV__ && false
 
+// TODO if we use it, add it here
+// <React.StrictMode>
+// </React.StrictMode>
 const Root = ({store, children}: any) => {
   return (
-    <React.StrictMode>
-      <GlobalKeyEventHandler>
-        <GatewayProvider>
-          <StyleContext.Provider value={{canFixOverdraw: true}}>
-            <Provider store={store}>{children}</Provider>
-          </StyleContext.Provider>
-        </GatewayProvider>
-      </GlobalKeyEventHandler>
-    </React.StrictMode>
+    <GlobalKeyEventHandler>
+      <GatewayProvider>
+        <CanFixOverdrawContext.Provider value={true}>
+          <Provider store={store}>{children}</Provider>
+        </CanFixOverdrawContext.Provider>
+      </GatewayProvider>
+    </GlobalKeyEventHandler>
   )
 }
 
