@@ -1,3 +1,3 @@
-import {Props} from './download-wrapper'
+import type {Props} from './download-wrapper'
 const DownloadWrapper = (props: Props) => props.children
 export default DownloadWrapper
