@@ -1,10 +1,10 @@
 // React-native tooling assumes this file is here, so we just require our real entry point
 /* eslint-disable @typescript-eslint/no-unsafe-assignment,@typescript-eslint/no-unsafe-argument,@typescript-eslint/no-unsafe-member-access */
-import 'react-native-gesture-handler' // MUST BE FIRST https://github.com/software-mansion/react-native-gesture-handler/issues/320
 import './why-did-you-render'
+import 'react-native-gesture-handler' // MUST BE FIRST https://github.com/software-mansion/react-native-gesture-handler/issues/320
 import './app/globals.native'
 import {Appearance} from 'react-native'
-import {NativeModules} from './util/native-modules.native'
+import {darkModeSupported, guiConfig} from 'react-native-kb'
 import {_setSystemIsDarkMode, _setSystemSupported, _setDarkModePreference} from './styles/dark-mode'
 import {enableES5, enableMapSet} from 'immer'
 enableES5()
@@ -12,10 +12,9 @@ enableMapSet()
 
 _setSystemIsDarkMode(Appearance.getColorScheme() === 'dark')
 
-const NativeEngine = NativeModules.KeybaseEngine
-_setSystemSupported(NativeEngine.darkModeSupported === '1')
+_setSystemSupported(darkModeSupported === '1')
 try {
-  const obj = JSON.parse(NativeEngine.guiConfig)
+  const obj = JSON.parse(guiConfig)
   const dm = obj?.ui?.darkMode
   switch (dm) {
     case 'system': // fallthrough
