@@ -5,7 +5,7 @@ import * as React from 'react'
 import * as Styles from '../styles'
 import useBrowserWindow from '../desktop/remote/use-browser-window.desktop'
 import useSerializeProps from '../desktop/remote/use-serialize-props.desktop'
-import {serialize, ProxyProps} from './remote-serializer.desktop'
+import {serialize, type ProxyProps} from './remote-serializer.desktop'
 
 const windowOpts = {height: 230, width: 440}
 
