@@ -1,4 +1,3 @@
-import * as React from 'react'
 import * as Kb from '../../../../common-adapters'
 import * as Container from '../../../../util/container'
 import * as RouteTreeGen from '../../../../actions/route-tree-gen'
@@ -15,10 +14,7 @@ const AddBotRow = (props: Props) => {
       RouteTreeGen.createNavigateAppend({
         path: [
           {
-            props: {
-              namespace: 'chat2',
-              teamID,
-            },
+            props: {teamID},
             selected: 'chatSearchBots',
           },
         ],
